install_mcsim: Download and install 'GNU MCSim'

View source: R/install.R

install_mcsimR Documentation

Download and install GNU MCSim

Description

Download and install the portable MCSim into the package folder.

Usage

install_mcsim(version = "6.2.0", mxstep = 5000)

find_mcsim()

mcsim_version()

makemcsim(model, mxstep = 500, deSolve = F, dir = NULL)

Arguments

version

a character of version number.

mxstep

a numeric value to assign the maximum number of (internally defined) steps

model

a string giving the name of the MCSim model file.

deSolve

a logical value to compile the MCSim model file to execute with deSolve package.

dir

a character to set the directory of the MCSim model file.

Details

The model generator program 'mod.exe' is used to compile the model code. It will be generated after the file download. The function can only use for version greater than 5.3.0. The Linux user need to make sure the gcc is pre-installed in your system. If you use Windows OS, be sure to install Rtools first. The Rtools can install through installr::install.rtools()

Functions

  • find_mcsim(): Check if MCSim had been installed correctly.

  • mcsim_version(): Check the version of MCSim that is currently installed.

  • makemcsim(): Compile the model file to the executable program.

References

Bois, F. Y., & Maszle, D. R. (1997). MCSim: a Monte Carlo simulation program. Journal of Statistical Software, 2(9): 1–60.

https://www.gnu.org/software/mcsim/


nanhung/RMCSim documentation built on Jan. 30, 2024, 3:45 a.m.