mcsim: Conduct MCSim in simulation

View source: R/mcsim.R

mcsimR Documentation

Conduct MCSim in simulation

Description

The function needs both MCSim model and input files to conduct the simulation.

Usage

mcsim(model, input, dir = NULL, parallel = F, check = F)

Arguments

model

a string giving the name of the MCSim model file.

input

a string giving the name of the MCSim input file.

dir

a character to set the directory of the MCSim model file.

parallel

a logical value to conduct parallel computing.


nanhung/RMCSim documentation built on Jan. 30, 2024, 3:45 a.m.