| mcsim | R Documentation |
The function needs both MCSim model and input files to conduct the simulation.
mcsim(model, input, dir = NULL, parallel = F, check = F)
model |
a string giving the name of the MCSim model file. |
input |
a string giving the name of the MCSim input file. |
dir |
a character to set the directory of the MCSim model file. |
parallel |
a logical value to conduct parallel computing. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.